@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2022 by Pascal Brachet                     *
  *   https://www.xm1math.net/algobox/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,11 +22,16 @@
 #include <QUrl>
 #include <QTimer>
 #include <QDebug>
+#include <QApplication>
+#include <QScreen>
+#include <QWindow>
+#include <QGuiApplication>
 
 
 Browser::Browser( const QString home, QWidget* parent)
     : QMainWindow( parent)
 {
+isClosed=false;
 setWindowTitle("AlgoBox");
 #if defined(Q_OS_MAC)
 setWindowIcon(QIcon(":/images/algobox128.png"));
@@ -80,7 +85,19 @@ pdffichier.remove("%");
 pdffichier=pdffichier+".pdf";
 QString tempDir=QDir::tempPath();
 pdffichier=tempDir+"/"+pdffichier;
-//resize(780,580 );
+
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+   QRect screen = QWidget::screen()->geometry();
+ #else
+  QRect screen = (window() && window()->windowHandle() ? window()->windowHandle()->screen()->geometry() : QGuiApplication::primaryScreen()->geometry());
+#endif
+int w= screen.width()/2;
+int h= screen.height()-150 ;
+int x= screen.width()/2;
+int y= 30 ;
+
+resize(w,h);
+move(x,y);
 }
 
 Browser::~Browser()
@@ -88,6 +105,12 @@ Browser::~Browser()
 
 }
 
+void Browser::closeEvent(QCloseEvent *e)
+{
+isClosed=true;
+e->accept();
+}
+
 void Browser::adjustTitle()
 {
 if (progress <= 0 || progress >= 100)
