@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2009-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2009-2022 by Pascal Brachet                     *
  *   https://www.xm1math.net/algobox/                                      *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -26,6 +26,7 @@ class Browser : public QMainWindow
 public:
     Browser( const QString home, QWidget* parent = 0);
     ~Browser();
+    bool isClosed;
 
 protected slots:
     void adjustTitle();
@@ -36,6 +37,7 @@ private slots:
   void Print();
   void Chercher();
 private:
+    void closeEvent(QCloseEvent *e);
     QWebEngineView *view;
     int progress;
     QLineEdit *searchLineEdit;
